==> kyuubi-hive-jdbc-shaded-1.7.0-sources.jar: org/apache/kyuubi/shade/org/apache/http/impl/client/HttpAuthenticator.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */

package org.apache.kyuubi.shade.org.apache.http.impl.client;

import org.apache.kyuubi.shade.org.apache.commons.logging.Log;
import org.apache.kyuubi.shade.org.apache.http.HttpHost;
import org.apache.kyuubi.shade.org.apache.http.HttpResponse;
import org.apache.kyuubi.shade.org.apache.http.auth.AuthState;
import org.apache.kyuubi.shade.org.apache.http.client.AuthenticationStrategy;
import org.apache.kyuubi.shade.org.apache.http.protocol.HttpContext;

/**
 * @deprecated (4.3) reserved for internal use.
 *
 */
@Deprecated
public class HttpAuthenticator extends org.apache.http.impl.auth.HttpAuthenticator {

    public HttpAuthenticator(final Log log) {
        super(log);
    }

    public HttpAuthenticator() {
        super();
    }

    public boolean authenticate (
            final HttpHost host,
            final HttpResponse response,
            final AuthenticationStrategy authStrategy,
            final AuthState authState,
            final HttpContext context) {
        return handleAuthChallenge(host, response, authStrategy, authState, context);
    }

}

==> kyuubi-hive-jdbc-shaded-1.9.1-sources.jar: org/apache/kyuubi/shade/org/apache/http/impl/client/HttpAuthenticator.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */

package org.apache.kyuubi.shade.org.apache.http.impl.client;

import org.apache.kyuubi.shade.org.apache.commons.logging.Log;
import org.apache.kyuubi.shade.org.apache.http.HttpHost;
import org.apache.kyuubi.shade.org.apache.http.HttpResponse;
import org.apache.kyuubi.shade.org.apache.http.auth.AuthState;
import org.apache.kyuubi.shade.org.apache.http.client.AuthenticationStrategy;
import org.apache.kyuubi.shade.org.apache.http.protocol.HttpContext;

/**
 * @deprecated (4.3) reserved for internal use.
 *
 */
@Deprecated
public class HttpAuthenticator extends org.apache.kyuubi.shade.org.apache.http.impl.auth.HttpAuthenticator {

    public HttpAuthenticator(final Log log) {
        super(log);
    }

    public HttpAuthenticator() {
        super();
    }

    public boolean authenticate (
            final HttpHost host,
            final HttpResponse response,
            final AuthenticationStrategy authStrategy,
            final AuthState authState,
            final HttpContext context) {
        return handleAuthChallenge(host, response, authStrategy, authState, context);
    }

}
